@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2002 Erez Zadok
+ * Copyright (c) 1997-2003 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: srvr_nfs.c,v 1.7.2.8 2002/09/09 14:59:53 ib42 Exp $
+ * $Id: srvr_nfs.c,v 1.7.2.10 2002/12/29 01:55:43 ib42 Exp $
  *
  */
 
@@ -606,21 +606,22 @@ nfs_srvr_port(fserver *fs, u_short *port, voidp wchan)
 static void
 start_nfs_pings(fserver *fs, int pingval)
 {
-  if (!(fs->fs_flags & FSF_PINGING)) {
-    fs->fs_flags |= FSF_PINGING;
-    if (fs->fs_cid)
-      untimeout(fs->fs_cid);
-    if (pingval < 0) {
-      srvrlog(fs, "wired up");
-      fs->fs_flags |= FSF_VALID;
-      fs->fs_flags &= ~FSF_DOWN;
-    } else {
-      nfs_keepalive(fs);
-    }
-  } else {
+  if (fs->fs_flags & FSF_PINGING) {
 #ifdef DEBUG
     dlog("Already running pings to %s", fs->fs_host);
 #endif /* DEBUG */
+    return;
+  }
+
+  if (fs->fs_cid)
+    untimeout(fs->fs_cid);
+  if (pingval < 0) {
+    srvrlog(fs, "wired up");
+    fs->fs_flags |= FSF_VALID;
+    fs->fs_flags &= ~FSF_DOWN;
+  } else {
+    fs->fs_flags |= FSF_PINGING;
+    nfs_keepalive(fs);
   }
 }
 
