@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2002 Erez Zadok
+ * Copyright (c) 1997-2003 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: hlfsd.c,v 1.7.2.5 2002/06/21 18:32:09 ezk Exp $
+ * $Id: hlfsd.c,v 1.7.2.7 2002/12/27 22:45:08 ezk Exp $
  *
  * HLFSD was written at Columbia University Computer Science Department, by
  * Erez Zadok <ezk@cs.columbia.edu> and Alexander Dupuy <dupuy@cs.columbia.edu>
@@ -934,17 +934,8 @@ fatal(char *mess)
       strcpy(lessmess, mess);
       lessmess[messlen - 4] = '\0';
 
-      if (errno < sys_nerr)
-	fprintf(stderr, "%s: %s: %s\n", am_get_progname(), lessmess,
-#ifdef HAVE_STRERROR
-		strerror(errno)
-#else /* not HAVE_STRERROR */
-		sys_errlist[errno]
-#endif /* not HAVE_STRERROR */
-		);
-      else
-	fprintf(stderr, "%s: %s: Error %d\n",
-		am_get_progname(), lessmess, errno);
+      fprintf(stderr, "%s: %s: %s\n",
+	      am_get_progname(), lessmess, strerror(errno));
     }
   }
   plog(XLOG_FATAL, "%s", mess);
