@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2002 Erez Zadok
+ * Copyright (c) 1997-2003 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: am_utils.h,v 1.11.2.10 2002/06/21 18:32:10 ezk Exp $
+ * $Id: am_utils.h,v 1.11.2.12 2002/12/27 22:45:10 ezk Exp $
  *
  */
 
@@ -948,6 +948,7 @@ extern void malloc_verify(void);
 
 /* functions that depend solely on debugging */
 extern void print_nfs_args(const nfs_args_t *nap, u_long nfs_version);
+extern int debug_option (char *opt);
 
 #else /* not DEBUG */
 
@@ -957,10 +958,16 @@ extern void print_nfs_args(const nfs_args_t *nap, u_long nfs_version);
  */
 #  define	XFREE(x) free(x)
 
+#define		amuDebug(x)	if (0)
+#define		dlog		if (0) dplog
+#define		amuDebugNo(x)	if (0)
+
+#define		print_nfs_args(nap, nfs_version)
+#define		debug_option(x)	(1)
+
 #endif /* not DEBUG */
 
 extern int debug_flags;		/* Debug options */
-extern int debug_option (char *opt);
 extern struct opt_tab dbg_opt[];
 extern void dplog(const char *fmt, ...)
      __attribute__ ((__format__ (__printf__, 1, 2)));
